@@ -103,12 +103,16 @@ kproto <- function (x, ...)
 #' 
 #' @rdname kproto
 #' 
-#' @importFrom stats complete.cases 
+#' @importFrom stats complete.cases
+#' @importFrom tibble is_tibble 
 #' 
 #' @method kproto default
 #' @export 
 kproto.default <- function(x, k, lambda = NULL, iter.max = 100, nstart = 1, na.rm = TRUE, keep.data = TRUE, verbose = TRUE, ...){
   
+  # enable input of tibbles
+  if(is_tibble(x) == TRUE){x <- as.data.frame(x)}
+  
   # initial error checks
   if(!is.data.frame(x)) stop("x should be a data frame!")
   if(ncol(x) < 2) stop("For clustering x should contain at least two variables!")
@@ -564,7 +568,7 @@ clprofiles <- function(object, x, vars = NULL, col = NULL){
       barplot(t(tab), beside = TRUE, main = colnames(x)[i], col = col)
     } 
   }
-  par(ask="FALSE")
+  par(ask=FALSE)
   invisible()
 }
 
