@@ -22,8 +22,9 @@ x4 <- c(rnorm(n, mean = -muk), rnorm(n, mean = muk), rnorm(n, mean = -muk), rnor
 
 x <- data.frame(x1,x2,x3,x4)
 
-kpres <- kproto.default(x, 4)
-kpres_w <- kproto.default(x, 4, keep.data = FALSE)
+kpres <- kproto.default(x, 4, verbose = FALSE)
+kpres_w <- kproto.default(x, 4, keep.data = FALSE, verbose = FALSE)
+kpres_1 <- kproto.default(x, 1, keep.data = FALSE, verbose = FALSE)
 
 
 
@@ -37,6 +38,9 @@ test_that("checking input objects",{
   expect_error(validation_kproto(method = "cindex", data = x, k = -1:3))
   expect_error(validation_kproto(method = "cindex", data = x, k = 5:43))
   expect_error(validation_kproto(method = "cindex", data = NULL, object = kpres_w))
+  expect_error(validation_kproto(method = "cindex", data = NULL, object = kpres_1))
+  expect_error(validation_kproto(method = "cindex", data = x, k = 1))
+  expect_error(validation_kproto(method = "cindex", data = x, k = 1:3))
 }
 )
 
@@ -44,6 +48,8 @@ test_that("checking input objects",{
 
 iv_cindex  <- validation_kproto(method = "cindex", object = kpres)
 ivk_cindex <- validation_kproto(method = "cindex", data = x, k = c(3:5))
+ivk_l_cindex <- validation_kproto(method = "cindex", object = NULL, data = x, k = c(3:5), 
+                                  kp_obj = 'optimal', lambda = 2)
 test_that("resulting objects based on cindex are as expected",{
   
   expect_is(iv_cindex, "numeric")
@@ -58,13 +64,17 @@ test_that("resulting objects based on cindex are as expected",{
   expect_true(is.numeric(ivk_cindex[[3]]))
   expect_true(length(ivk_cindex[[3]]) <= 3)
   expect_equal(ivk_cindex[[1]], as.integer(names(which.min(ivk_cindex[[3]]))))
+  
+  expect_equal(ivk_l_cindex$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_dunn  <- validation_kproto(method = "dunn", object = kpres)
-ivk_dunn <- validation_kproto(method = "dunn", data = x, k = c(3:5))
+iv_dunn  <- validation_kproto(method = "dunn", object = kpres, verbose = FALSE)
+ivk_dunn <- validation_kproto(method = "dunn", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_dunn <- validation_kproto(method = "dunn", object = NULL, data = x, k = c(3:5), 
+                                  kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on dunn index are as expected",{
   
   expect_is(iv_dunn, "numeric")
@@ -78,13 +88,17 @@ test_that("resulting objects based on dunn index are as expected",{
   expect_true(is.numeric(ivk_dunn[[3]]))
   expect_true(length(ivk_dunn[[3]]) <= 3)
   expect_equal(ivk_dunn[[1]], as.integer(names(which.max(ivk_dunn[[3]]))))
+  
+  expect_equal(ivk_l_dunn$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_gamma  <- validation_kproto(method = "gamma", object = kpres)
-ivk_gamma <- validation_kproto(method = "gamma", data = x, k = c(3:5))
+iv_gamma  <- validation_kproto(method = "gamma", object = kpres, verbose = FALSE)
+ivk_gamma <- validation_kproto(method = "gamma", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_gamma <- validation_kproto(method = "gamma", object = NULL, data = x, k = c(3:5), 
+                                kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on gamma index are as expected",{
   
   expect_is(iv_gamma, "numeric")
@@ -99,13 +113,17 @@ test_that("resulting objects based on gamma index are as expected",{
   expect_true(is.numeric(ivk_gamma[[3]]))
   expect_true(length(ivk_gamma[[3]]) <= 3)
   expect_equal(ivk_gamma[[1]], as.integer(names(which.max(ivk_gamma[[3]]))))
+  
+  expect_equal(ivk_l_gamma$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_gplus  <- validation_kproto(method = "gplus", object = kpres)
-ivk_gplus <- validation_kproto(method = "gplus", data = x, k = c(3:5))
+iv_gplus  <- validation_kproto(method = "gplus", object = kpres, verbose = FALSE)
+ivk_gplus <- validation_kproto(method = "gplus", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_gplus <- validation_kproto(method = "gplus", object = NULL, data = x, k = c(3:5), 
+                            kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on gplus index are as expected",{
   
   expect_is(iv_gplus, "numeric")
@@ -120,13 +138,17 @@ test_that("resulting objects based on gplus index are as expected",{
   expect_true(is.numeric(ivk_gplus[[3]]))
   expect_true(length(ivk_gplus[[3]]) <= 3)
   expect_equal(ivk_gplus[[1]], as.integer(names(which.min(ivk_gplus[[3]]))))
+  
+  expect_equal(ivk_l_gplus$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_mcclain  <- validation_kproto(method = "mcclain", object = kpres)
-ivk_mcclain <- validation_kproto(method = "mcclain", data = x, k = c(3:5))
+iv_mcclain  <- validation_kproto(method = "mcclain", object = kpres, verbose = FALSE)
+ivk_mcclain <- validation_kproto(method = "mcclain", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_mcclain <- validation_kproto(method = "mcclain", object = NULL, data = x, k = c(3:5), 
+                            kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on mcclain index are as expected",{
   
   expect_is(iv_mcclain, "numeric")
@@ -140,13 +162,17 @@ test_that("resulting objects based on mcclain index are as expected",{
   expect_true(is.numeric(ivk_mcclain[[3]]))
   expect_true(length(ivk_mcclain[[3]]) <= 3)
   expect_equal(ivk_mcclain[[1]], as.integer(names(which.min(ivk_mcclain[[3]]))))
+  
+  expect_equal(ivk_l_mcclain$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_ptbiserial  <- validation_kproto(method = "ptbiserial", object = kpres)
-ivk_ptbiserial <- validation_kproto(method = "ptbiserial", data = x, k = c(3:5))
+iv_ptbiserial  <- validation_kproto(method = "ptbiserial", object = kpres, verbose = FALSE)
+ivk_ptbiserial <- validation_kproto(method = "ptbiserial", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_ptbiserial <- validation_kproto(method = "ptbiserial", object = NULL, data = x, k = c(3:5), 
+                            kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on ptbiserial index are as expected",{
   
   expect_is(iv_ptbiserial, "numeric")
@@ -159,13 +185,17 @@ test_that("resulting objects based on ptbiserial index are as expected",{
   expect_true(is.numeric(ivk_ptbiserial[[3]]))
   expect_true(length(ivk_ptbiserial[[3]]) <= 3)
   expect_equal(ivk_ptbiserial[[1]], as.integer(names(which.max(ivk_ptbiserial[[3]]))))
+  
+  expect_equal(ivk_l_ptbiserial$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_silhouette  <- validation_kproto(method = "silhouette", object = kpres)
-ivk_silhouette <- validation_kproto(method = "silhouette", data = x, k = c(3:5))
+iv_silhouette  <- validation_kproto(method = "silhouette", object = kpres, verbose = FALSE)
+ivk_silhouette <- validation_kproto(method = "silhouette", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_silhouette <- validation_kproto(method = "silhouette", object = NULL, data = x, k = c(3:5), 
+                            kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on silhouette index are as expected",{
   
   expect_is(iv_silhouette, "numeric")
@@ -180,13 +210,17 @@ test_that("resulting objects based on silhouette index are as expected",{
   expect_true(is.numeric(ivk_silhouette[[3]]))
   expect_true(length(ivk_silhouette[[3]]) <= 3)
   expect_equal(ivk_silhouette[[1]], as.integer(names(which.max(ivk_silhouette[[3]]))))
+  
+  expect_equal(ivk_l_silhouette$kp_obj$lambda, 2)
 }
 )
 
 
 
-iv_tau  <- validation_kproto(method = "tau", object = kpres)
-ivk_tau <- validation_kproto(method = "tau", data = x, k = c(3:5))
+iv_tau  <- validation_kproto(method = "tau", object = kpres, verbose = FALSE)
+ivk_tau <- validation_kproto(method = "tau", data = x, k = c(3:5), verbose = FALSE)
+ivk_l_tau <- validation_kproto(method = "tau", object = NULL, data = x, k = c(3:5), 
+                            kp_obj = 'optimal', lambda = 2, verbose = FALSE)
 test_that("resulting objects based on tau index are as expected",{
   
   expect_is(iv_tau, "numeric")
@@ -201,6 +235,8 @@ test_that("resulting objects based on tau index are as expected",{
   expect_true(is.numeric(ivk_tau[[3]]))
   expect_true(length(ivk_tau[[3]]) <= 3)
   expect_equal(ivk_tau[[1]], as.integer(names(which.max(ivk_tau[[3]]))))
+  
+  expect_equal(ivk_l_tau$kp_obj$lambda, 2)
 }
 )
 
